@@ -671,7 +671,7 @@ class Aka(callbacks.Plugin):
                             }), 'user', 'something'])
 
     def show(self, irc, msg, args, optlist, name):
-        """<command>
+        """[--channel <#channel>] <alias>
 
         This command shows the content of an Aka.
         """
@@ -686,7 +686,7 @@ class Aka(callbacks.Plugin):
         if command:
             irc.reply(command)
         else:
-            irc.error(_('This Aka does not exist'))
+            irc.error(_('This Aka does not exist.'))
     show = wrap(show, [getopts({'channel': 'somethingWithoutSpaces'}),
         'text'])
 
