@@ -43,6 +43,8 @@ import random
 from local import dictclient
 
 class Dict(callbacks.Plugin):
+    """This plugin provides a function to look up words from different
+    dictionaries."""
     threaded = True
     @internationalizeDocstring
     def dictionaries(self, irc, msg, args):
