@@ -58,7 +58,13 @@ try:
 except ImportError:
     parse = None
 
+try:
+    from dateutil.tz import tzlocal
+except ImportError:
+    tzlocal = None
+
 class Time(callbacks.Plugin):
+    """This plugin allows you to use different time-related functions."""
     @internationalizeDocstring
     def seconds(self, irc, msg, args):
         """[<years>y] [<weeks>w] [<days>d] [<hours>h] [<minutes>m] [<seconds>s]
@@ -160,7 +166,13 @@ class Time(callbacks.Plugin):
                 format = self.registryValue('format', channel)
             else:
                 format = self.registryValue('format')
-        irc.reply(time.strftime(format, time.localtime(seconds)))
+        if tzlocal:
+            irc.reply(datetime.fromtimestamp(seconds, tzlocal()).strftime(format))
+        else:
+            # NOTE: This has erroneous behavior on some older Python versions,
+            # including at least up to 2.7.5 and 3.2.3. Install dateutil if you
+            # can't upgrade Python.
+            irc.reply(time.strftime(format, time.localtime(seconds)))
     time = wrap(time, [optional('channel'), optional('nonInt'),
                        additional('float', TIME.time)])
 
@@ -191,7 +203,7 @@ class Time(callbacks.Plugin):
         except pytz.UnknownTimeZoneError:
             irc.error(_('Unknown timezone'))
             return
-        irc.reply(str(datetime.now(timezone)))
+        irc.reply(datetime.now(timezone).strftime('%F %T%z'))
     tztime = wrap(tztime, ['text'])
 
 
