@@ -70,6 +70,10 @@ class Title(HTMLParser.HTMLParser):
             if name in self.entitydefs:
                 self.title += self.entitydefs[name]
 
+    def handle_charref(self, name):
+        if self.inTitle:
+            self.title += unichr(int(name))
+
 class DelayedIrc:
     def __init__(self, irc):
         self._irc = irc
@@ -275,7 +279,7 @@ class Web(callbacks.PluginRegexp):
         parser = Title()
         if sys.version_info[0] >= 3 and isinstance(text, bytes):
             irc.error(_('Could not guess the page\'s encoding. (Try '
-                    'installing python-charade'), Raise=True)
+                    'installing python-charade.)'), Raise=True)
         try:
             parser.feed(text)
         except HTMLParser.HTMLParseError:
