@@ -410,8 +410,8 @@ class IrcState(IrcCommandDispatcher):
         # msg.args = [nick, server, ircd-version, umodes, modes,
         #             modes that require arguments? (non-standard)]
         self.ircd = msg.args[2]
-        self.supported['umodes'] = msg.args[3]
-        self.supported['chanmodes'] = msg.args[4]
+        self.supported['umodes'] = frozenset(msg.args[3])
+        self.supported['chanmodes'] = frozenset(msg.args[4])
 
     _005converters = utils.InsensitivePreservingDict({
         'modes': int,
@@ -483,13 +483,24 @@ class IrcState(IrcCommandDispatcher):
 
     def do352(self, irc, msg):
         # WHO reply.
+
         (nick, user, host) = (msg.args[5], msg.args[2], msg.args[3])
         hostmask = '%s!%s@%s' % (nick, user, host)
         self.nicksToHostmasks[nick] = hostmask
 
+    def do354(self, irc, msg):
+        # WHOX reply.
+
+        if len(msg.args) != 6 or msg.args[1] != '1':
+            return
+
+        (__, ___, user, host, nick, ___) = msg.args
+        hostmask = '%s!%s@%s' % (nick, user, host)
+        self.nicksToHostmasks[nick] = hostmask
+
     def do353(self, irc, msg):
         # NAMES reply.
-        (_, type, channel, names) = msg.args
+        (__, type, channel, names) = msg.args
         if channel not in self.channels:
             self.channels[channel] = ChannelState()
         c = self.channels[channel]
@@ -927,65 +938,88 @@ class Irc(IrcCommandDispatcher):
         if self.zombie:
             self.driver.die()
             self._reallyDie()
-        else:
-            if self.sasl_password:
-                if not self.sasl_username:
-                    log.warning('%s: SASL username is not set, unable to '
-                                'identify.', self.network)
-                else:
-                    log.debug("%s: Requesting capability 'sasl'.",
-                              self.network)
-                    self.queueMsg(ircmsgs.IrcMsg(command='CAP', args=('REQ', 'sasl')))
-            if self.password:
-                log.info('%s: Queuing PASS command, not logging the password.',
-                         self.network)
-                self.queueMsg(ircmsgs.password(self.password))
-            log.debug('%s: Queuing NICK command, nick is %s.',
-                      self.network, self.nick)
-            self.queueMsg(ircmsgs.nick(self.nick))
-            log.debug('%s: Queuing USER command, ident is %s, user is %s.',
-                      self.network, self.ident, self.user)
-            self.queueMsg(ircmsgs.user(self.ident, self.user))
 
-    def doAuthenticate(self, msg):
-        if msg.args[0] == '+':
-            log.info('%s: Authenticating using SASL.', self.network)
+            return
 
-            authstring = base64.b64encode('\0'.join([
-                self.sasl_username,
-                self.sasl_username,
-                self.sasl_password
-            ]).encode('utf-8')).decode('utf-8')
+        self.sasl = None
 
-            self.queueMsg(ircmsgs.IrcMsg(command='AUTHENTICATE', args=(authstring,)))
-        else:
-            log.error('%s: Unexpected response from server: %s',
-                      self.network, msg)
+        if (conf.supybot.networks.get(self.network).certfile() or
+                conf.supybot.protocols.irc.certfile()):
+            self.sasl = 'external'
+        elif self.sasl_username and self.sasl_password:
+            self.sasl = 'plain'
+
+        if self.sasl:
+            self.queueMsg(ircmsgs.IrcMsg(command='CAP', args=('REQ', 'sasl')))
+
+        self.queueMsg(ircmsgs.IrcMsg(command='CAP', args=('REQ', 'account-notify')))
+        self.queueMsg(ircmsgs.IrcMsg(command='CAP', args=('REQ', 'extended-join')))
+
+        if not self.sasl:
             self.queueMsg(ircmsgs.IrcMsg(command='CAP', args=('END',)))
 
+        if self.password:
+            log.info('%s: Queuing PASS command, not logging the password.',
+                     self.network)
+
+            self.queueMsg(ircmsgs.password(self.password))
+
+        log.debug('%s: Queuing NICK command, nick is %s.',
+                  self.network, self.nick)
+
+        self.queueMsg(ircmsgs.nick(self.nick))
+
+        log.debug('%s: Queuing USER command, ident is %s, user is %s.',
+                  self.network, self.ident, self.user)
+
+        self.queueMsg(ircmsgs.user(self.ident, self.user))
+
+    def doAuthenticate(self, msg):
+        if len(msg.args) == 1 and msg.args[0] == '+':
+            log.info('%s: Authenticating using SASL.', self.network)
+
+            if self.sasl == 'external':
+                authstring = '+'
+            elif self.sasl == 'plain':
+                authstring = base64.b64encode('\0'.join([
+                    self.sasl_username,
+                    self.sasl_username,
+                    self.sasl_password
+                ]).encode('utf-8')).decode('utf-8')
+
+            self.queueMsg(ircmsgs.IrcMsg(command='AUTHENTICATE', args=(authstring,)))
+
     def doCap(self, msg):
-        if msg.args[2] == 'sasl':
-            if msg.args[1] == 'ACK':
-                log.debug("%s: Server acknowledged 'sasl' capability",
-                          self.network)
-                self.queueMsg(ircmsgs.IrcMsg(command='AUTHENTICATE',
-                                             args=('PLAIN',)))
-            elif msg.args[1] == 'NAK':
-                log.warning("%s: Server refused 'sasl' capability",
-                            self.network)
-                self.queueMsg(ircmsgs.IrcMsg(command='CAP', args=('END',)))
-            else:
-                log.error('%s: Unexpected response from server: %s',
-                          self.network, msg)
-                self.queueMsg(ircmsgs.IrcMsg(command='CAP', args=('END',)))
+        if len(msg.args) == 3:
+            for cap in msg.args[2].split(' '):
+                if msg.args[1] == 'ACK':
+                    log.info('%s: Server acknowledged capability %r',
+                             self.network, cap)
+
+                    if cap == 'sasl':
+                        self.queueMsg(ircmsgs.IrcMsg(
+                            command='AUTHENTICATE',
+                            args=(self.sasl.upper(),)))
+                elif msg.args[1] == 'NAK':
+                    log.warning('%s: Server refused capability %r',
+                                self.network, cap)
 
     def do903(self, msg):
         log.info('%s: SASL authentication successful', self.network)
         self.queueMsg(ircmsgs.IrcMsg(command='CAP', args=('END',)))
 
     def do904(self, msg):
-        log.warning('%s: SASL authentication failed', self.network)
-        self.queueMsg(ircmsgs.IrcMsg(command='CAP', args=('END',)))
+        if (self.sasl == 'external' and self.sasl_username and
+                self.sasl_password):
+            log.info('%s: SASL EXTERNAL failed, trying PLAIN.', self.network)
+
+            self.sasl = 'plain'
+
+            self.queueMsg(ircmsgs.IrcMsg(
+                command='AUTHENTICATE', args=(self.sasl.upper(),)))
+        else:
+            log.warning('%s: SASL authentication failed', self.network)
+            self.queueMsg(ircmsgs.IrcMsg(command='CAP', args=('END',)))
 
     def do905(self, msg):
         log.warning('%s: SASL authentication failed because the username or '
@@ -1051,13 +1085,10 @@ class Irc(IrcCommandDispatcher):
         if umodes == '':
             umodes = conf.supybot.protocols.irc.umodes()
         supported = self.state.supported.get('umodes')
+        if supported:
+            acceptedchars = supported.union('+-')
+            umodes = ''.join([m for m in umodes if m in acceptedchars])
         if umodes:
-            addSub = '+'
-            if umodes[0] in '+-':
-                (addSub, umodes) = (umodes[0], umodes[1:])
-            if supported:
-                umodes = ''.join([m for m in umodes if m in supported])
-            umodes = ''.join([addSub, umodes])
             log.info('Sending user modes to %s: %s', self.network, umodes)
             self.sendMsg(ircmsgs.mode(self.nick, umodes))
     do377 = do422 = do376
@@ -1076,7 +1107,7 @@ class Irc(IrcCommandDispatcher):
     def doJoin(self, msg):
         if msg.nick == self.nick:
             channel = msg.args[0]
-            self.queueMsg(ircmsgs.who(channel)) # Ends with 315.
+            self.queueMsg(ircmsgs.who(channel, args=('%tuhna,1',))) # Ends with 315.
             self.queueMsg(ircmsgs.mode(channel)) # Ends with 329.
             for channel in msg.args[0].split(','):
                 self.queueMsg(ircmsgs.mode(channel, '+b'))
